pub struct PathAsymmetry { /* private fields */ }Expand description
Forward-vs-reverse path asymmetry. The forward hop count is what the peer reports about our packets; the reverse is what we observe about the peer’s.
Implementations
Sourceimpl PathAsymmetry
impl PathAsymmetry
pub fn new() -> Self
Sourcepub fn observe_forward(&mut self, hops: u8)
pub fn observe_forward(&mut self, hops: u8)
Record the forward hop count (from the peer’s Path frame about us).
Sourcepub fn observe_reverse(&mut self, hops: u8)
pub fn observe_reverse(&mut self, hops: u8)
Record the reverse hop count (from our received-TTL cmsg about the peer).
pub fn forward(&self) -> Option<u8>
pub fn reverse(&self) -> Option<u8>