SharedBitVec

Struct SharedBitVec 

pub struct SharedBitVec { /* private fields */ }

Implementations

Source

impl SharedBitVec

pub fn create( path: impl AsRef<Path>, capacity_bits: usize, ) -> Result<Self, BitVecError>

pub fn open( path: impl AsRef<Path>, expected_capacity_bits: usize, ) -> Result<Self, BitVecError>

pub fn capacity_bits(&self) -> usize

pub fn capacity_words(&self) -> usize

pub fn set(&self, i: usize) -> Result<bool, BitVecError>

Set bit i to 1. Returns the previous value at that bit.

pub fn clear(&self, i: usize) -> Result<bool, BitVecError>

Clear bit i to 0. Returns the previous value at that bit.

pub fn toggle(&self, i: usize) -> Result<bool, BitVecError>

Flip bit i. Returns the new value at that bit.

pub fn get(&self, i: usize) -> Result<bool, BitVecError>

Read bit i.

pub fn set_range(&self, lo: usize, hi: usize) -> Result<(), BitVecError>

Set all bits in lo..hi (exclusive end). Uses RMW on boundary words and unconditional store on interior words.

pub fn clear_range(&self, lo: usize, hi: usize) -> Result<(), BitVecError>

Clear all bits in lo..hi (exclusive end). Same RMW-on- boundary, store-on-interior pattern.

pub fn count_ones(&self) -> usize

Count total number of 1-bits across all words. O(words).

pub fn count_zeros(&self) -> usize

Count total number of 0-bits in the valid range.

pub fn is_all_set(&self) -> bool

pub fn is_all_clear(&self) -> bool

pub fn set_all(&self)

Set every bit. Unconditional Release-store on every word, with the last word masked to only valid bits so count_ones stays accurate.

pub fn clear_all(&self)

Clear every bit.

pub fn flush(&self) -> Result<(), BitVecError>

pub fn flush_async(&self) -> Result<(), BitVecError>